﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Infragistics.UltraChart.Core.Primitives;
using Infragistics.UltraChart.Data.Series;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;

namespace _141066
{
    public partial class Form1 : Form
    {
        class VectorSettings
        {
            SymbolIconSize iconSize;

            public SymbolIconSize IconSize
            {
                get { return iconSize; }
                set { iconSize = value; }
            }
            SymbolIcon icon;

            public SymbolIcon Icon
            {
                get { return icon; }
                set {icon = value; }
            }
            SplineAppearance lineAppearance;

            

            public SplineAppearance LineAppearance
            {
                get { return lineAppearance; }
                set { lineAppearance = value; }

            }

        }
        Dictionary<ISeries, VectorSettings> seriesApp = new Dictionary<ISeries, VectorSettings>();

        public Form1()
        {
            InitializeComponent();
        }

        private static readonly Random random = new Random();

        private void button1_Click(object sender, EventArgs e)
        {
             ultraChart1.Series.Clear();
             seriesApp.Clear();
            for (int i = 0 ; i < (int)numericUpDown1.Value; i++)
            {
                XYSeries series = new XYSeries();
                series.Key = string.Format("Series{0}", i);
                series.Label = series.Key;

                //use this if you want the point to have a label
                XYDataPoint p1 = getRandomPoint("");
                XYDataPoint p2 = getRandomPoint(string.Format("{0} P2", series.Key));

                series.Points.Add(p1);
                series.Points.Add(p2);

                Color c = GetRandomColor();
                series.PEs.Add(new PaintElement() { Stroke = c, Fill = c});
                
                ultraChart1.Series.Add(series);
                seriesApp.Add(series, new VectorSettings()
                {
                    
                    Icon = ((SymbolIcon)(i % Enum.GetValues(typeof(SymbolIcon)).Length)),
                    IconSize = SymbolIconSize.Medium,
                    LineAppearance = new SplineAppearance() { DrawStyle = ((LineDrawStyle)(i % Enum.GetValues(typeof(LineDrawStyle)).Length)) }
                });
            }

            ultraChart1.DataBind();

        }

        private XYDataPoint getRandomPoint(string label)
        {
            int x = random.Next(0, 100);
            int y = random.Next(0, (3 * x) % 100);
            return new XYDataPoint(x, y, label, false);
        }

        private Color GetRandomColor()
        {
            return Color.FromArgb(random.Next(0, 255), random.Next(0,255),random.Next(0,255));
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ultraChart1.Axis.X.RangeMax = 100;
            ultraChart1.Axis.Y.RangeMax = 100;
            ultraChart1.Axis.X.RangeMin = 0;
            ultraChart1.Axis.Y.RangeMin = 0;

            ultraChart1.Axis.X.RangeType = Infragistics.UltraChart.Shared.Styles.AxisRangeType.Custom;
            ultraChart1.Axis.Y.RangeType = Infragistics.UltraChart.Shared.Styles.AxisRangeType.Custom;

            ultraChart1.ScatterChart.ConnectWithLines = true;
            ultraChart1.ScatterChart.ChartText.Add(new ChartTextAppearance() { ChartTextFont = new System.Drawing.Font("Arial", 7F),
                                                                               ClipText = false,
                                                                               Column = -2,
                                                                               Row = -2,
                                                                               ItemFormatString = "<ITEM_LABEL>", 
                                                                               FontColor = Color.Black, 
                                                                               Visible = true });

            //use for the legend symbol
            ultraChart1.ScatterChart.Icon = SymbolIcon.Circle;
            

        }

        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
           List<PointSet> pointSeries = e.SceneGraph.Cast<Primitive>().
               Where(p => p is PointSet).Cast<PointSet>().ToList();
           foreach (PointSet seriesPoints in pointSeries)
           {
               if (seriesPoints.Series != null && seriesApp.ContainsKey(seriesPoints.Series))
               {
                   seriesPoints.icon =  SymbolIcon.None;
                   //add a new PointSet in order to have a starting symbol for the first point
                   DataPoint[] newPoint = new DataPoint[] { seriesPoints.points[0] };
                   PointSet newPointSet = new PointSet(newPoint, ultraChart1.Font, 'X');
                   newPointSet.icon = seriesApp[seriesPoints.Series].Icon;
                   newPointSet.iconSize = seriesApp[seriesPoints.Series].IconSize;
                   newPointSet.PE = seriesPoints.PE;
                   e.SceneGraph.Add(newPointSet);
               }
           }

           IEnumerable<Polyline> lineSeries = (IEnumerable<Polyline>)e.SceneGraph.Cast<Primitive>().
               Where(p => p is Polyline).Cast<Polyline>();
           foreach (Polyline seriesLine in lineSeries)
           {
               if (seriesLine.Row > -1 && seriesLine.Column == seriesLine.Row)
               {
                   seriesLine.lineStyle.DrawStyle = seriesApp.Values.Skip(seriesLine.Row).
                       Take(1).First().LineAppearance.DrawStyle;
               }
           }

        }  
    }
}
